#ifndef NT2_INCLUDE_CONSTANTS_DIGITS_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_DIGITS_HPP_INCLUDED

#include <nt2/constant/include/constants/digits.hpp>

#endif
